"""Migrate the Archivematica agent version string to Archivematica-1.13.
"""
from django.db import migrations


DOWN_VERSION = "Archivematica-1.12"
UP_VERSION = "Archivematica-1.13"


def data_migration_down(apps, _):
    """Undo the migration if requested."""
    agent = apps.get_model("main", "Agent")
    agent.objects.filter(
        identifiertype="preservation system", name="Archivematica"
    ).update(identifiervalue=DOWN_VERSION)


def data_migration_up(apps, _):
    """Update the application agent version in the database."""
    agent = apps.get_model("main", "Agent")
    agent.objects.filter(
        identifiertype="preservation system", name="Archivematica"
    ).update(identifiervalue=UP_VERSION)


class Migration(migrations.Migration):
    """Run the migration to update the Archivematica agent version string."""

    dependencies = [("main", "0078_username_check")]

    operations = [migrations.RunPython(data_migration_up, data_migration_down)]
